// Poisson Model

data {
	
	// Define variables in data
	//Indices
	int<lower=0> n_obs;
	int<lower=0> n_species;
	int<lower=0> n_sites;
	int<lower=0> n_params;
	int<lower=0, upper=n_species> species[n_obs];
	int<lower=0, upper=9> site[n_obs];

	//Response variable
	int<lower=0> counts[n_obs];

	//Covariates
	matrix[n_obs,n_params] X;
	vector[n_obs] effort;

}

parameters {
	
	// Parameters to estimate
	vector[n_params] beta_mean;
	vector<lower=0>[n_params] beta_var;
	real<lower=0> obs_var;
	real<lower=0> site_var;
	matrix[n_params,n_species] beta;
	vector[n_obs] eps;
	vector[n_sites] site_effect;

}

transformed parameters {

	vector<lower=0>[n_params] beta_sd;
	real obs_sd;
	real site_sd;
	vector[n_obs] lp;

	beta_sd = sqrt(beta_var);
	obs_sd = sqrt(obs_var);
	site_sd = sqrt(site_var);
	
	for (i in 1:n_obs){
		lp[i] = X[i,] * beta[,species[i]] 
		+ site_effect[site[i]] + eps[i]
		+ effort[i];
	}

}

model {

	//Weak priors	
	//hyperpriors
	beta_mean ~ normal(0,1);
	beta_var ~ normal(0,1);
	
	site_var ~ normal(0,1);
	obs_var ~ normal(0,1);

	site_effect ~ normal(0,site_sd);
	eps ~ normal(0,obs_sd);

	for (i in 1:n_params){
		beta[i,] ~ normal(beta_mean[i],beta_sd[i]);
	}

	//Model response
	counts ~ poisson_log(lp);

}

generated quantities {

	int<lower=0> yrep[n_obs];
	
	for (i in 1:n_obs){	
		yrep[i] = poisson_log_rng(lp[i]);
	}

}

