// Poisson Model

data {
	
	// Define variables in data
	//Indices
	int<lower=0> n_obs;
	int<lower=0> n_sites;
	int<lower=0> n_params;
	int<lower=0, upper=9> site[n_obs];

	//Response variable
	int<lower=0> richness[n_obs];

	//Covariates
	matrix[n_obs,n_params] X;
	vector[n_obs] effort;

}

parameters {
	
	// Parameters to estimate
	real<lower=0> obs_var;
	real<lower=0> site_var;
	vector[n_params] beta;
	vector[n_obs] eps;
	vector[n_sites] site_effect;

}

transformed parameters {

	real obs_sd;
	real site_sd;
	vector[n_obs] lp;

	obs_sd = sqrt(obs_var);
	site_sd = sqrt(site_var);
	
	for (i in 1:n_obs){
		lp[i] = X[i,] * beta 
		+ site_effect[site[i]] + eps[i]
		+ effort[i];
	}

}

model {

	//Weak priors	
	beta ~ normal(0,1);
	
	site_var ~ normal(0,1);
	obs_var ~ normal(0,1);

	site_effect ~ normal(0,site_sd);
	eps ~ normal(0,obs_sd);

	//Model response
	richness ~ poisson_log(lp);

}

generated quantities {

	int<lower=0> yrep[n_obs];
	
	for (i in 1:n_obs){	
		yrep[i] = poisson_log_rng(lp[i]);
	}

}

