#==============================================================================
#	Script to Clean Harvest Treatment Data
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
suppressMessages(library(sf))			#Spatial data tools
library(tidyverse)				#Data processing tools
#==============================================================================

#====Load Spatial Data=========================================================
options(warn=-1)

#MOFEP geodatabase
mofep_db = '../data/MOFEP.gdb'

#Get treatment data
treat06 = st_read(mofep_db,layer='TREATMENTS_1996',quiet=T) %>%
	st_set_geometry(NULL) %>%
	as_tibble() %>%
	unite(Stand,SITE_ID,STAND_ID) %>%
	distinct() %>%
	mutate(Treat06 = case_when(
			TREATMENT=='CC' ~ 'regen',
			TREATMENT=='INT' ~ 'thin',
			TREATMENT=='NONE' ~ 'noharvest',
			TREATMENT=='UAM' ~ 'singletree')) %>%
	select(Stand,Treat06) %>%
	distinct() %>%
	arrange(Stand)

treat11 = st_read(mofep_db,layer='TREATMENTS_2011',quiet=T) %>%
	st_set_geometry(NULL) %>%
	as_tibble() %>%
	unite(Stand,SITE_ID,STAND_ID) %>%
	select(Stand,PRES_DESC) %>%
	distinct() %>%
	mutate(Treat11 = case_when(
      str_detect(PRES_DESC,'REGEN|CLEARCUT') ~ 'regen',
			str_detect(PRES_DESC,'INTERMED') ~ 'thin',
			str_detect(PRES_DESC,'SINGLE') ~ 'singletree',
			str_detect(PRES_DESC,'LEAVE|OLD GROWTH') ~ 'noharvest',
			TRUE ~ 'TSI/other')) %>%
	select(Stand,Treat11) %>%
	arrange(Stand)

treatment_clean = treat06 %>%
	full_join(treat11, by='Stand') %>%
	arrange(Stand)

options(warn=0)
#==============================================================================

save(treatment_clean,file='clean_treatment_data.Rdata')
