#==============================================================================
#	Script to Compile Input Data for Stan
#==============================================================================

#====Dependencies==============================================================
options(tidyverse.quiet=TRUE)
library(tidyverse)				#Data processing tools
#==============================================================================

#====Load data files===========================================================

load('clean_smam_data.Rdata')
load('clean_bird_data.Rdata')
load('clean_herp_data.Rdata')
load('clean_treatment_data.Rdata')

#==============================================================================

#====Combine Species and Treatment Data========================================

species_tidy = birds_clean %>%
	filter(Species %in% c('ACFL','BAWW','EAWP','HOWO','INBU','KEWA',
						  'OVEN','NOPA','PRAW','SCTA','SUTA','WOTH',
						  'WEWA','YBCU','YBCH')) %>%
	rename(Effort = Area) %>%
	mutate(Taxa = 'bird') %>%
	bind_rows(herps_clean %>%
			  mutate(Taxa = 'herp')
			  ) %>%
	bind_rows(smams_clean %>%
			  mutate(Taxa = 'smam'))

add_site = species_tidy %>%
	separate(Stand, into=c('Site','StandNo'), remove=FALSE, convert=TRUE) %>%
	mutate(Treat = case_when(Site %in% c(1,6,8) ~ 'noharvest',
							 Site %in% c(2,4,7) ~ 'uneven',
							 Site %in% c(3,5,9) ~ 'even')) %>%
	bind_cols(as_tibble(model.matrix(~Treat -1, data=.)[,-2])) %>%
	select(-Treat)

add_harvest = add_site %>%
	left_join(treatment_clean, by='Stand') %>%
	replace_na(list(Treat06='noharvest',Treat11='noharvest')) %>%
	rename(H06 = Treat06, H11 = Treat11) %>%
	bind_cols(as_tibble(model.matrix( ~ H06 -1, data=.)[,-1])) %>%
	bind_cols(as_tibble(model.matrix( ~ H11 -1, data=.)[,-1])) %>%
	select(-H06, -H11)

add_time = add_harvest %>%
	mutate(After06 = ifelse(Year > 1996,1,0),
		   After11 = ifelse(Year > 2011,1,0),
		   Since06 = ifelse((Year - 1996 > 0),(Year - 1996), NA),
		   Since11 = ifelse((Year - 2011 > 0),(Year - 2011), NA))

#==============================================================================

#====Subset to get final dataset===============================================

stan_input = add_time %>%
  filter(`H11TSI/other` == 0) %>%
  select(-`H11TSI/other`)

save(stan_input,smam_codes,bird_codes,herp_codes,file='stan_input.Rdata')

#==============================================================================
